@@ -1,6 +1,6 @@
 from django.http import HttpRequest
 
-from photo_objects.django import Size
+from photo_objects.django.conf import PhotoSize
 from photo_objects.django.models import Album, Photo
 
 from photo_objects.django.api.utils import (
@@ -16,7 +16,7 @@ def check_album_access(request: HttpRequest, album_key: str):
     try:
         album = Album.objects.get(key=album_key)
     except Album.DoesNotExist:
-        raise AlbumNotFound(album_key)
+        raise AlbumNotFound(album_key) from None
 
     if not request.user.is_authenticated:
         if album.visibility == Album.Visibility.PRIVATE:
@@ -35,19 +35,19 @@ def check_photo_access(
         photo_key: str,
         size_key: str):
     try:
-        size = Size(size_key)
+        size = PhotoSize(size_key)
     except ValueError:
-        raise InvalidSize(size_key)
+        raise InvalidSize(size_key) from None
 
     try:
         photo = Photo.objects.get(key=join_key(album_key, photo_key))
     except Photo.DoesNotExist:
-        raise PhotoNotFound(album_key, photo_key)
+        raise PhotoNotFound(album_key, photo_key) from None
 
     if not request.user.is_authenticated:
         if photo.album.visibility == Album.Visibility.PRIVATE:
             raise AlbumNotFound(album_key)
-        if size == Size.ORIGINAL:
+        if size == PhotoSize.ORIGINAL:
             raise Unauthorized()
 
     return photo
