@@ -2,6 +2,8 @@ from django.apps import AppConfig
 from django.core.checks import Error, register
 from django.conf import settings
 
+from photo_objects.django.conf import validate_photo_sizes
+
 
 class PhotoObjects(AppConfig):
     default_auto_field = 'django.db.models.BigAutoField'
@@ -17,7 +19,7 @@ def photo_objects_check(app_configs, **kwargs):
     errors = []
 
     try:
-        conf = settings.PHOTO_OBJECTS_OBJSTO
+        objsto_conf = settings.PHOTO_OBJECTS_OBJSTO
     except AttributeError:
         errors.append(
             Error(
@@ -29,7 +31,7 @@ def photo_objects_check(app_configs, **kwargs):
         return errors
 
     for key in ('URL', 'ACCESS_KEY', 'SECRET_KEY',):
-        if not conf.get(key):
+        if not objsto_conf.get(key):
             errors.append(
                 Error(
                     f'The PHOTO_OBJECTS_OBJSTO setting must define {key} '
@@ -38,4 +40,14 @@ def photo_objects_check(app_configs, **kwargs):
                     obj='photo_objects',
                 ))
 
+    try:
+        sizes_conf = settings.PHOTO_OBJECTS_PHOTO_SIZES
+        errors.extend(
+            validate_photo_sizes(
+                sizes_conf,
+                'The PHOTO_OBJECTS_PHOTO_SIZES'))
+    except AttributeError:
+        # Use default values if sizes are not configured
+        pass
+
     return errors
