@@ -1,6 +1,8 @@
+from datetime import datetime
 from django import template
 
-from photo_objects.django.models import Album
+from photo_objects.django.models import SiteSettings
+from photo_objects.django.views.utils import meta_description
 
 
 register = template.Library()
@@ -25,6 +27,11 @@ def display_name(user):
     return user.username
 
 
+@register.filter
+def is_datetime(value):
+    return isinstance(value, datetime)
+
+
 @register.filter
 def is_list(value):
     return isinstance(value, list)
@@ -41,13 +48,14 @@ def meta_og(context):
     try:
         request = context.get("request")
         site = request.site
-        album = Album.objects.get(key=f'_site_{site.id}')
+
+        settings = SiteSettings.objects.get(site)
 
         return {
             'request': request,
-            "title": album.title or site.name,
-            "description": album.description,
-            "photo": album.cover_photo,
+            "title": site.name,
+            "description": meta_description(request, settings.description),
+            "photo": settings.preview_image,
         }
     except Exception:
         return context
